@@ -16,27 +16,32 @@
 #'   \code{"reqq"} is a QQ-plot for random effects and only available for mixed models.
 #'   \code{"ncv"} checks for non-constant variance, i.e. for heteroscedasticity.
 #'   By default, all possible checks are performed and plotted.
+#' @param alpha The alpha level of the confidence bands. Scalar from 0 to 1.
 #' @param ... Currently not used.
 #'
 #' @return The data frame that is used for plotting.
 #'
 #' @note This function just prepares the data for plotting. To create the plots,
-#' \CRANpkg{see} needs to be installed.
+#' \CRANpkg{see} needs to be installed. Furthermore, this function suppresses
+#' all possible warnings. In case you observe suspicious plots, please refer to
+#' the dedicated functions (like \code{check_collinearity()}, \code{check_normality()}
+#' etc.) to get informative messages and warnings.
 #'
 #' @examples
 #' \dontrun{
 #' m <- lm(mpg ~ wt + cyl + gear + disp, data = mtcars)
 #' check_model(m)
 #'
-#' library(lme4)
-#' m <- lmer(Reaction ~ Days + (Days | Subject), sleepstudy)
-#' check_model(m, panel = FALSE)
-#'
-#' library(rstanarm)
-#' m <- stan_glm(mpg ~ wt + gear, data = mtcars, chains = 2, iter = 200)
-#' check_model(m)
+#' if (require("lme4")) {
+#'   m <- lmer(Reaction ~ Days + (Days | Subject), sleepstudy)
+#'   check_model(m, panel = FALSE)
 #' }
 #'
+#' if (require("rstanarm")) {
+#'   m <- stan_glm(mpg ~ wt + gear, data = mtcars, chains = 2, iter = 200)
+#'   check_model(m)
+#' }
+#' }
 #' @export
 check_model <- function(x, ...) {
   UseMethod("check_model")
@@ -45,15 +50,15 @@ check_model <- function(x, ...) {
 
 #' @rdname check_model
 #' @export
-check_model.default <- function(x, dot_size = 2, line_size = .8, panel = TRUE, check = "all", ...) {
+check_model.default <- function(x, dot_size = 2, line_size = .8, panel = TRUE, check = "all", alpha = .2, ...) {
   minfo <- insight::model_info(x)
 
   if (minfo$is_bayesian) {
-    ca <- .check_assumptions_stan(x)
+    ca <- suppressWarnings(.check_assumptions_stan(x))
   } else if (minfo$is_linear) {
-    ca <- .check_assumptions_linear(x, minfo)
+    ca <- suppressWarnings(.check_assumptions_linear(x, minfo))
   } else {
-    ca <- .check_assumptions_glm(x, minfo)
+    ca <- suppressWarnings(.check_assumptions_glm(x, minfo))
   }
   # else {
   #   stop(paste0("`check_assumptions()` not implemented for models of class '", class(x)[1], "' yet."), call. = FALSE)
@@ -63,6 +68,7 @@ check_model.default <- function(x, dot_size = 2, line_size = .8, panel = TRUE, c
   attr(ca, "dot_size") <- dot_size
   attr(ca, "line_size") <- line_size
   attr(ca, "check") <- check
+  attr(ca, "alpha") <- alpha
 
   ca
 }
@@ -113,7 +119,7 @@ check_model.default <- function(x, dot_size = 2, line_size = .8, panel = TRUE, c
     # check if brms can be loaded
 
     if (!requireNamespace("brms", quietly = TRUE)) {
-      stop("Package `brms` needs to be loaded first!", call. = F)
+      stop("Package `brms` needs to be loaded first!", call. = FALSE)
     }
 
     # check if prior sample are available
@@ -134,7 +140,7 @@ check_model.default <- function(x, dot_size = 2, line_size = .8, panel = TRUE, c
 
     # check if rstanarm can be loaded
     if (!requireNamespace("rstanarm", quietly = TRUE)) {
-      stop("Package `rstanarm` needs to be loaded first!", call. = F)
+      stop("Package `rstanarm` needs to be loaded first!", call. = FALSE)
     }
 
 
