@@ -1,5 +1,5 @@
 #' @export
-logLik.felm <- function(object, ...) {
+logLik.ivreg <- function(object, ...) {
   res <- object$residuals
   p <- object$rank
   w <- object$weights
@@ -29,11 +29,7 @@ logLik.felm <- function(object, ...) {
 }
 
 
-#' @export
-logLik.ivreg <- logLik.felm
-
-
-#' @importFrom insight find_parameters
+#' @importFrom insight find_parameters get_df
 #' @export
 logLik.plm <- function(object, ...) {
   res <- object$residuals
@@ -57,7 +53,7 @@ logLik.plm <- function(object, ...) {
 
   attr(val, "nall") <- N0
   attr(val, "nobs") <- N
-  attr(val, "df") <- length(insight::find_parameters(object, effects = "fixed", flatten = TRUE))
+  attr(val, "df") <- insight::get_df(object, type = "model")
   class(val) <- "logLik"
 
   val
@@ -68,10 +64,10 @@ logLik.cpglm <- logLik.plm
 
 
 
-#' @importFrom stats residuals
+#' @importFrom insight get_residuals
 #' @export
 logLik.iv_robust <- function(object, ...) {
-  res <- stats::residuals(object)
+  res <- insight::get_residuals(object)
   p <- object$rank
   w <- object$weights
 
@@ -98,3 +94,18 @@ logLik.iv_robust <- function(object, ...) {
 
   val
 }
+
+
+
+
+#' @importFrom insight n_obs
+#' @export
+logLik.svycoxph <- function(object, ...) {
+  val <- object$ll[2]
+  attr(val, "nall") <- insight::n_obs(object)
+  attr(val, "nobs") <- insight::n_obs(object)
+  attr(val, "df") <- object$degf.resid
+  class(val) <- "logLik"
+
+  val
+}
