@@ -42,7 +42,7 @@ model_performance.lm <- function(model, metrics = "all", verbose = TRUE, ...) {
     metrics <- c("AIC", "BIC", "R2", "R2_adj", "RMSE")
   }
 
-  info <- insight::model_info(model)
+  info <- suppressWarnings(insight::model_info(model))
 
   ## TODO remove is.list() once insight 0.8.3 is on CRAN
   if (is.null(info) || !is.list(info)) {
@@ -52,39 +52,110 @@ model_performance.lm <- function(model, metrics = "all", verbose = TRUE, ...) {
   out <- list()
   attrib <- list()
 
+  # AIC -------------
   if ("AIC" %in% toupper(metrics)) {
-    out$AIC <- performance_aic(model)
+    out$AIC <- tryCatch({
+      performance_aic(model)
+    },
+    error = function(e) {
+      NULL
+    })
   }
+
+  # BIC -------------
   if ("BIC" %in% toupper(metrics)) {
-    out$BIC <- .get_BIC(model)
+    out$BIC <- tryCatch({
+      .get_BIC(model)
+    },
+    error = function(e) {
+      NULL
+    })
   }
+
+  # R2 -------------
   if ("R2" %in% toupper(metrics)) {
-    R2 <- r2(model)
-    attrib$r2 <- attributes(R2)
-    out <- c(out, R2)
+    R2 <- tryCatch({
+      r2(model, verbose = verbose)
+    },
+    error = function(e) {
+      NULL
+    })
+    if (!is.null(R2)) {
+      attrib$r2 <- attributes(R2)
+      out <- c(out, R2)
+    }
   }
+
+  # RMSE -------------
   if ("RMSE" %in% toupper(metrics)) {
-    out$RMSE <- performance_rmse(model, verbose = verbose)
+    out$RMSE <- tryCatch({
+      performance_rmse(model, verbose = verbose)
+    },
+    error = function(e) {
+      NULL
+    })
   }
+
+  # SIGMA -------------
   if ("SIGMA" %in% toupper(metrics)) {
-    out$Sigma <- .get_sigma(model)
+    out$Sigma <- tryCatch({
+      .get_sigma(model)
+    },
+    error = function(e) {
+      NULL
+    })
   }
+
+  # LOGLOSS -------------
   if (("LOGLOSS" %in% toupper(metrics)) && isTRUE(info$is_binomial)) {
-    .logloss <- performance_logloss(model, verbose = verbose)
-    if (!is.na(.logloss)) out$Log_loss <- .logloss
+    out$Log_loss <- tryCatch({
+      .logloss <- performance_logloss(model, verbose = verbose)
+      if (!is.na(.logloss)) {
+        .logloss
+      } else {
+        NULL
+      }
+    },
+    error = function(e) {
+      NULL
+    })
   }
+
+  # SCORE -------------
   if (("SCORE" %in% toupper(metrics)) && (isTRUE(info$is_binomial) || isTRUE(info$is_count))) {
-    .scoring_rules <- performance_score(model, verbose = verbose)
-    if (!is.na(.scoring_rules$logarithmic)) out$Score_log <- .scoring_rules$logarithmic
-    if (!is.na(.scoring_rules$spherical)) out$Score_spherical <- .scoring_rules$spherical
+    .scoring_rules <- tryCatch({
+      performance_score(model, verbose = verbose)
+    },
+    error = function(e) {
+      NULL
+    })
+    if (!is.null(.scoring_rules)) {
+      if (!is.na(.scoring_rules$logarithmic)) out$Score_log <- .scoring_rules$logarithmic
+      if (!is.na(.scoring_rules$spherical)) out$Score_spherical <- .scoring_rules$spherical
+    }
   }
-  if (("PCP" %in% toupper(metrics)) && isTRUE(info$is_binomial) && !isTRUE(info$is_multinomial) && !isTRUE(info$is_ordinal)) {
-    out$PCP <- performance_pcp(model, verbose = verbose)$pcp_model
+
+  # PCP -------------
+  if (("PCP" %in% toupper(metrics)) && isTRUE(info$is_binomial) && isFALSE(info$is_multinomial) && isFALSE(info$is_ordinal)) {
+    out$PCP <- tryCatch({
+      performance_pcp(model, verbose = verbose)$pcp_model
+    },
+    error = function(e) {
+      NULL
+    })
   }
 
-  # TODO: What with sigma and deviance?
 
   out <- as.data.frame(.compact_list(out, remove_na = TRUE))
+
+  # check if model was actually supported...
+  if (nrow(out) == 0 || ncol(out) == 0) {
+    if (isTRUE(verbose)) {
+      warning(paste0("Models of class '", class(model)[1], "' are not yet supported."), call. = FALSE)
+    }
+    return(NULL)
+  }
+
   row.names(out) <- NULL
   class(out) <- c("performance_model", class(out))
 
@@ -127,9 +198,6 @@ model_performance.felm <- model_performance.lm
 #' @export
 model_performance.iv_robust <- model_performance.lm
 
-#' @export
-model_performance.ivreg <- model_performance.lm
-
 #' @export
 model_performance.multinom <- model_performance.lm
 
@@ -222,3 +290,20 @@ model_performance.mlogit <- function(model, metrics = "all", verbose = TRUE, ...
     NULL
   }
 }
+
+
+#' @export
+model_performance.margins <- function(model, metrics = "all", verbose = TRUE, ...) {
+  orig_mod_call <- attributes(model)$call
+  model_performance(eval(orig_mod_call), metrics = metrics, verbose = verbose, ...)
+}
+
+
+#' @export
+model_performance.sem <- function(model, metrics = "all", verbose = TRUE, ...) {
+  if (inherits(model, "sem") && inherits(model, "lme")) {
+    model_performance.lm(model, metrics = metrics, verbose = verbose, ...)
+  } else {
+    NULL
+  }
+}
