@@ -18,8 +18,7 @@
 #' data(mtcars)
 #' m <- lm(mpg ~ hp + gear, data = mtcars)
 #' performance_mse(m)
-#' @importFrom insight print_color
-#' @importFrom stats residuals
+#' @importFrom insight get_residuals
 #' @export
 performance_mse <- function(model, ...) {
   UseMethod("performance_mse")
@@ -35,23 +34,31 @@ mse <- performance_mse
 performance_mse.default <- function(model, verbose = TRUE, ...) {
   res <- tryCatch(
     {
-      if (inherits(model, c("vgam", "vglm"))) {
-        model@residuals
-      } else {
-        stats::residuals(model)
-      }
-    },
-    error = function(e) {
+      insight::get_residuals(model, verbose = verbose, type = "response", ...)
+    }, error = function(e) {
       NULL
     }
   )
 
+  if (is.null(res)) {
+    res <- tryCatch(
+      {
+        def_res <- insight::get_residuals(model, verbose = verbose, ...)
+        if (verbose) {
+          warning("Response residuals not available to calculate mean square error. (R)MSE is probably not reliable.", call. = FALSE)
+        }
+        def_res
+      }, error = function(e) {
+        NULL
+      }
+    )
+  }
+
   if (is.null(res) || all(is.na(res))) {
-    if (verbose) insight::print_color("Can't extract residuals from model.\n", "red")
     return(NA)
   }
 
-  mean(res^2, na.rm = T)
+  mean(res^2, na.rm = TRUE)
 }
 
 
@@ -60,8 +67,8 @@ performance_mse.default <- function(model, verbose = TRUE, ...) {
 # mfx models -------------------------------
 
 #' @export
-performance_mse.logitor <- function(model, ...) {
-  performance_mse(model$fit, ...)
+performance_mse.logitor <- function(model, verbose = TRUE, ...) {
+  performance_mse(model$fit, verbose = verbose, ...)
 }
 
 #' @export
