@@ -19,7 +19,7 @@
 #' For \code{stan_lmer()} and \code{stan_glmer()} models, the predicted values
 #' are based on \code{posterior_predict()}, instead of \code{predict()}. Thus,
 #' results may differ more than expected from their non-Bayesian counterparts
-#' in \pkg{lme4}.
+#' in \strong{lme4}.
 #'
 #' @references Carvalho, A. (2016). An overview of applications of proper scoring rules. Decision Analysis 13, 223–242. \doi{10.1287/deca.2016.0337}
 #'
@@ -161,25 +161,32 @@ performance_score <- function(model, verbose = TRUE) {
   pred <- NULL
   pred_zi <- NULL
 
-  if (inherits(model, "MixMod")) {
-    pred <- stats::predict(model, type = "subject_specific")
-    pred_zi <- if (!is.null(model$gammas)) attr(pred, "zi_probs")
-  } else if (inherits(model, "glmmTMB")) {
-    pred <- stats::predict(model, type = "response")
-    pred_zi <- stats::predict(model, type = "zprob")
-  } else if (inherits(model, c("hurdle", "zeroinfl"))) {
-    pred <- stats::predict(model, type = "response")
-    pred_zi <- stats::predict(model, type = "zero")
-  } else if (inherits(model, c("clm", "clm2", "clmm"))) {
-    pred <- stats::predict(model)
-  } else if (all(inherits(model, c("stanreg", "lmerMod"), which = TRUE)) > 0) {
-    if (!requireNamespace("rstanarm", quietly = TRUE)) {
-      stop("Package `rstanarm` required for this function to work. Please install it.")
+  tryCatch(
+    {
+      if (inherits(model, "MixMod")) {
+        pred <- stats::predict(model, type = "subject_specific")
+        pred_zi <- if (!is.null(model$gammas)) attr(pred, "zi_probs")
+      } else if (inherits(model, "glmmTMB")) {
+        pred <- stats::predict(model, type = "response")
+        pred_zi <- stats::predict(model, type = "zprob")
+      } else if (inherits(model, c("hurdle", "zeroinfl"))) {
+        pred <- stats::predict(model, type = "response")
+        pred_zi <- stats::predict(model, type = "zero")
+      } else if (inherits(model, c("clm", "clm2", "clmm"))) {
+        pred <- stats::predict(model)
+      } else if (all(inherits(model, c("stanreg", "lmerMod"), which = TRUE)) > 0) {
+        if (!requireNamespace("rstanarm", quietly = TRUE)) {
+          stop("Package `rstanarm` required for this function to work. Please install it.")
+        }
+        pred <- colMeans(rstanarm::posterior_predict(model))
+      } else {
+        pred <- stats::predict(model, type = "response")
+      }
+    },
+    error = function(e) {
+      return(NULL)
     }
-    pred <- colMeans(rstanarm::posterior_predict(model))
-  } else {
-    pred <- stats::predict(model, type = "response")
-  }
+  )
 
   list(pred = pred, pred_zi = pred_zi)
 }
