@@ -603,21 +603,25 @@ print.check_collinearity <- function(x, ...) {
 
 #' @importFrom insight export_table print_color format_p
 #' @export
-print.performance_lrt <- function(x, digits = 2, ...) {
-  insight::print_color("# Likelihood-Ratio-Test for Model Comparison\n\n", "blue")
+print.test_likelihoodratio <- function(x, digits = 2, ...) {
+
+  # Footer
+  if ("LogLik" %in% names(x)) {
+    best <- which.max(x$LogLik)
+    footer <- c(sprintf("\nModel '%s' seems to have the best model fit.\n", x$Model[best]), "yellow")
+  } else{
+    footer <- NULL
+  }
 
   # value formatting
-  x$AIC <- round(x$AIC)
-  if ("BIC" %in% colnames(x)) x$BIC <- round(x$BIC)
   x$p <- insight::format_p(x$p, name = NULL)
 
-  cat(insight::export_table(x, digits = digits))
-
-  if (sum(x$p < .05, na.rm = TRUE) <= 1) {
-    best <- which(x$p < .05)
-    if (length(best) == 0) best <- 1
-    insight::print_color(sprintf("\nModel '%s' seems to have the best model fit.\n", x$Model[best]), "yellow")
-  }
+  cat(insight::export_table(
+    x,
+    digits = digits,
+    caption = c("# Likelihood-Ratio-Test (LRT) for Model Comparison", "blue"),
+    footer = footer
+  ))
 
   invisible(x)
 }
@@ -627,13 +631,13 @@ print.performance_lrt <- function(x, digits = 2, ...) {
 #' @importFrom insight print_color export_table
 #' @export
 print.check_itemscale <- function(x, digits = 2, ...) {
-  insight::print_color("# Description of (Sub-)Scales\n", "blue")
+  insight::print_color("# Description of (Sub-)Scales", "blue")
 
   cat(insight::export_table(
     lapply(1:length(x), function(i) {
       out <- x[[i]]
-      attr(out, "table_caption") <- c(sprintf("Component %i", i), "red")
-      attr(out, "table_footer") <- c(sprintf("Mean inter-item-correlation = %.3f  Cronbach's alpha = %.3f",
+      attr(out, "table_caption") <- c(sprintf("\nComponent %i", i), "red")
+      attr(out, "table_footer") <- c(sprintf("\nMean inter-item-correlation = %.3f  Cronbach's alpha = %.3f",
                                              attributes(out)$item_intercorrelation,
                                              attributes(out)$cronbachs_alpha), "yellow")
 
@@ -645,41 +649,3 @@ print.check_itemscale <- function(x, digits = 2, ...) {
     zap_small = TRUE
   ))
 }
-
-
-
-
-
-
-# helper -------------------------------
-
-#' @importFrom insight format_value
-.format_df_columns <- function(x) {
-  # generic df
-  if ("df" %in% names(x)) x$df <- insight::format_value(x$df, protect_integers = TRUE)
-  # residual df
-  if ("df_residual" %in% names(x)) x$df_residual <- insight::format_value(x$df_residual, protect_integers = TRUE)
-  names(x)[names(x) == "df_residual"] <- "df"
-  # df for errors
-  if ("df_error" %in% names(x)) x$df_error <- insight::format_value(x$df_error, protect_integers = TRUE)
-  names(x)[names(x) == "df_error"] <- "df"
-  # denominator and numerator df
-  if ("df_num" %in% names(x)) x$df_num <- insight::format_value(x$df_num, protect_integers = TRUE)
-  if ("df_denom" %in% names(x)) x$df_denom <- insight::format_value(x$df_denom, protect_integers = TRUE)
-  x
-}
-
-
-#' @importFrom stats na.omit
-.format_freq_stats <- function(x) {
-  stats <- "CochransQ"
-  if (stats %in% names(x) && "df" %in% names(x)) {
-    df <- stats::na.omit(unique(x$df))
-    if (length(df) == 1 && !all(is.infinite(df))) {
-      names(x)[names(x) == stats] <- paste0(stats, "(", df, ")")
-      x$df <- NULL
-    }
-  }
-
-  x
-}
