@@ -56,8 +56,11 @@ r2.default <- function(model, verbose = TRUE, ...) {
 #' @importFrom stats pf
 #' @export
 r2.lm <- function(model, ...) {
-  model_summary <- summary(model)
+  .r2_lm(summary(model))
+}
 
+
+.r2_lm <- function(model_summary) {
   out <- list(
     R2 = model_summary$r.squared,
     R2_adjusted = model_summary$adj.r.squared
@@ -83,6 +86,13 @@ r2.lm <- function(model, ...) {
 
 
 
+#' @export
+r2.summary.lm <- function(model, ...) {
+  .r2_lm(model)
+}
+
+
+
 #' @export
 r2.ols <- function(model, ...) {
   out <- list(R2 = model$stats["R2"])
