@@ -1,7 +1,17 @@
+osx <- tryCatch({
+  si <- Sys.info()
+  if (!is.null(si["sysname"])) {
+    si["sysname"] == "Darwin" || grepl("^darwin", R.version$os)
+  } else {
+    FALSE
+  }
+})
+
+
 .runThisTest <- Sys.getenv("RunAllperformanceTests") == "yes"
 
-if (.runThisTest) {
-  if (require("testthat") && require("performance") && require("lme4") && require("insight")) {
+if (.runThisTest && !osx) {
+  if (require("testthat") && require("performance") && require("lme4") && require("nlme") && require("insight")) {
     data(iris)
     m0 <- lm(Sepal.Length ~ Petal.Length, data = iris)
     m1 <- lmer(Sepal.Length ~ Petal.Length + (1 | Species), data = iris)
@@ -69,5 +79,13 @@ if (.runThisTest) {
         tolerance = 0.05
       )
     })
+
+    data(iris)
+    m <- nlme::lme(Sepal.Length ~ Petal.Length, random = ~1 | Species, data = iris)
+    out <- icc(m)
+    test_that("icc", {
+      expect_equal(out$ICC_adjusted, 0.9104331, tolerance = 0.01)
+      expect_equal(out$ICC_conditional, 0.3109478, tolerance = 0.01)
+    })
   }
 }
